<h1>Registry</h1>
<div class="photon-docu-header">
    <p>
        The PHOTONAI <a href='../../api/base/registry'>Registry class</a> lets you register your class with a key, 
        so that you can access it conveniently in your PHOTONAI 
        <a href='../../api/base/hyperpipe'>Hyperpipe</a>. setup via the 
        <a href='../../api/base/pipeline_element'>PipelineElement class</a>.
    </p>
</div>

``` python
{% include "examples/basic/register_elements.py" %} 

```